pub struct SizedPool<T: Default> {
head: Option<NonZeroUsize>,
_marker: PhantomData<T>,
}๐Deprecated: Will be removed soon. Do not use!
A pool allocator that allocates fixed-size blocks.
Fields
head: Option<NonZeroUsize>๐Deprecated: Will be removed soon. Do not use!
_marker: PhantomData<T>๐Deprecated: Will be removed soon. Do not use!
Implementations
Sourceimpl<T: Default> SizedPool<T>
impl<T: Default> SizedPool<T>
Sourceconst fn align_up() -> usize
const fn align_up() -> usize
Calculate the padding required to align the block to align_of::<T>().
Sourcepub unsafe fn add_range(&mut self, range: Range<usize>)
pub unsafe fn add_range(&mut self, range: Range<usize>)
Add a range of blocks to the pool.
range - The range of blocks to add.
Safety
The caller must ensure that the range is valid and that the blocks are at least the size of T + SizedPoolMeta + Padding for T.
Sourceunsafe fn add_block(&mut self, ptr: usize)
unsafe fn add_block(&mut self, ptr: usize)
Add a block to the pool.
ptr - The pointer to the block to add.
Safety
The caller must ensure that the pointer is valid and that the block is at least the size of T + SizedPoolMeta + Padding for T.